@@ -941,12 +941,13 @@ pub mod repr_cstring;
 pub mod result;
 pub mod slice;
 pub mod trait_group;
+pub mod tuple;
 pub mod vec;
 
 pub use ::cglue_macro::{
     as_mut, as_ref, cast, cglue_forward, cglue_forward_ext, cglue_impl_group, cglue_trait,
-    cglue_trait_ext, cglue_trait_group, group_obj, int_result, into, no_int_result, return_wrap,
-    skip_func, trait_obj, vtbl_only, wrap_with, wrap_with_group, wrap_with_group_mut,
+    cglue_trait_ext, cglue_trait_group, custom_impl, group_obj, int_result, into, no_int_result,
+    return_wrap, skip_func, trait_obj, vtbl_only, wrap_with, wrap_with_group, wrap_with_group_mut,
     wrap_with_group_ref, wrap_with_obj, wrap_with_obj_mut, wrap_with_obj_ref,
 };
 
@@ -975,6 +976,7 @@ pub mod prelude {
             result::{CResult, IntError, IntResult},
             slice::{CSliceMut, CSliceRef},
             trait_group::Opaquable,
+            tuple::*,
             vec::CVec,
             *,
         };
